@@ -1,5 +1,6 @@
 from django.db.models.query import QuerySet
 from django.test import TestCase
+from django.utils.unittest import expectedFailure
 
 from example_project.polls.models import Poll
 
@@ -14,6 +15,19 @@ class BaseDjangoObjectActionsTest(TestCase):
     def setUp(self):
         self.instance = BaseDjangoObjectActions()
 
+    def test_get_object_actions_gets_attribute(self):
+        mock_objectactions = []  # set to something mutable
+        mock_request = 'request'
+        mock_context = 'context'
+        mock_kwargs = {}
+        self.instance.objectactions = mock_objectactions
+        returned_value = self.instance.get_object_actions(
+            mock_request, mock_context, **mock_kwargs
+        )
+        # assert that `mock_objectactions` was returned
+        self.assertEqual(id(mock_objectactions), id(returned_value))
+        # WISHLIST assert get_object_actions was called with right args
+
     def test_get_djoa_button_attrs_returns_defaults(self):
         mock_tool = type('mock_tool', (object, ), {})
         attrs, __ = self.instance.get_djoa_button_attrs(mock_tool)
@@ -35,7 +49,6 @@ class BaseDjangoObjectActionsTest(TestCase):
         attrs, __ = self.instance.get_djoa_button_attrs(mock_tool)
         self.assertEqual(attrs['title'], 'real title')
 
-
     def test_get_djoa_button_attrs_gets_set(self):
         mock_tool = type('mock_tool', (object, ), {
             'attrs': {'class': 'class'},
@@ -68,6 +81,25 @@ class QuerySetIshTest(TestCase):
         self.assertEqual(qs.filter().get(), self.obj)
         self.assertEqual(qs.latest('bar'), self.obj)
 
+    def test_queryset_supports_delete(self):
+        qs = QuerySetIsh(self.obj)
+        qs.delete()
+        with self.assertRaises(Poll.DoesNotExist):
+            Poll.objects.get(pk=1)
+
+    @expectedFailure
+    def test_queryset_supports_filter(self):
+        # yeah, we don't actually support doing this, but it would be nice.
+        qs = QuerySetIsh(self.obj)
+        with self.assertRaises(Poll.DoesNotExist):
+            # this should be empty because the question is just `"hi"`
+            qs.filter(question='abra cadabra').get()
+
+    def test_queryset_supports_update(self):
+        qs = QuerySetIsh(self.obj)
+        qs.update(question='mooo')
+        self.assertEqual(Poll.objects.get(pk=1).question, 'mooo')
+
 
 class DecoratorTest(TestCase):
     def setUp(self):
