@@ -47,14 +47,20 @@ class BaseDjangoObjectActions(object):
                 custom_attrs=custom_attrs,
             )
 
-        context['objectactions'] = [to_dict(x) for x in self.objectactions]
-        return super(BaseDjangoObjectActions, self).render_change_form(request,
-            context, **kwargs)
+        context['objectactions'] = [
+            to_dict(x) for x in
+            self.get_object_actions(request, context, **kwargs)
+        ]
+        return super(BaseDjangoObjectActions, self).render_change_form(
+            request, context, **kwargs)
 
     ##################
     # CUSTOM METHODS #
     ##################
 
+    def get_object_actions(self, request, context, **kwargs):
+        return self.objectactions
+
     def get_djoa_button_attrs(self, tool):
         attrs = getattr(tool, 'attrs', {})
         # href is not allowed to be set. should an exception be raised instead?
@@ -119,6 +125,7 @@ class QuerySetIsh(QuerySet):
             # Django 1.5 does this instead, getting the model may be overkill
             # we may be able to throw away all this logic
             model = instance._meta.concrete_model
+        self._doa_instance = instance
         super(QuerySetIsh, self).__init__(model, *args, **kwargs)
         self._result_cache = [instance]
 
@@ -126,6 +133,12 @@ class QuerySetIsh(QuerySet):
         # don't clone me, bro
         return self
 
+    def get(self, *args, **kwargs):
+        # Starting in Django 1.7, `QuerySet.get` started slicing to
+        # `MAX_GET_RESULTS`, so to avoid messing with `__getslice__`, override
+        # `.get`.
+        return self._doa_instance
+
 
 def takes_instance_or_queryset(func):
     """Decorator that makes standard actions compatible."""
